test/unittest_entity.py
branchstable
changeset 9214 be05b42b4825
parent 9160 7db0c75acf1c
child 9261 1dfe62a9da50
child 9273 f3795da61959
--- a/test/unittest_entity.py	Thu Aug 01 13:55:11 2013 +0200
+++ b/test/unittest_entity.py	Tue Aug 06 11:20:07 2013 +0200
@@ -692,16 +692,16 @@
         person.cw_clear_all_caches()
         self.assertEqual(person.rest_path(), unicode(person.eid))
         self.assertEqual(person2.rest_path(), unicode(person2.eid))
-        # unique attr with None value (wikiid in this case)
-        card1 = req.create_entity('Card', title=u'hop')
-        self.assertEqual(card1.rest_path(), unicode(card1.eid))
+        # unique attr with None value (nom in this case)
+        friend = req.create_entity('Ami', prenom=u'bob')
+        self.assertEqual(friend.rest_path(), unicode(friend.eid))
         # don't use rest if we have /, ? or & in the path (breaks mod_proxy)
-        card2 = req.create_entity('Card', title=u'pod', wikiid=u'zo/bi')
-        self.assertEqual(card2.rest_path(), unicode(card2.eid))
-        card3 = req.create_entity('Card', title=u'pod', wikiid=u'zo&bi')
-        self.assertEqual(card3.rest_path(), unicode(card3.eid))
-        card4 = req.create_entity('Card', title=u'pod', wikiid=u'zo?bi')
-        self.assertEqual(card4.rest_path(), unicode(card4.eid))
+        person3 = req.create_entity('Personne', nom=u'zo/bi')
+        self.assertEqual(person3.rest_path(), unicode(person3.eid))
+        person4 = req.create_entity('Personne', nom=u'zo&bi')
+        self.assertEqual(person4.rest_path(), unicode(person4.eid))
+        person5 = req.create_entity('Personne', nom=u'zo?bi')
+        self.assertEqual(person5.rest_path(), unicode(person5.eid))
 
 
     def test_cw_set_attributes(self):